@@ -1,9 +1,9 @@
 #!/usr/bin/env python
 # -*- encoding:utf-8 -*-
 
-from .gamess import Gamess, GamessError
+from .gamess import Gamess, GamessError, logger
 
-__version__ = "0.5.0"
+__version__ = "0.6.2"
 __all__ = ["Gamess"]
 
 
